@@ -27,15 +27,16 @@ class Task(ABC):
 
     def _set_end_time(self):
         end_time = datetime.now().strftime('%d/%m/%y %H:%M:%S')
-        self.TASK_DAO.set_end_time_by_task_id(self.id, end_time)
+        self.TASK_DAO.set_end_time_by_task_id(self.task_id, end_time)
 
     def _set_task_status(self, status):
-        self.TASK_DAO.set_task_status(self.id, status)
+        self.TASK_DAO.set_task_status(self.task_id, status)
 
     def _save_task_result(self, payload: Payload, layer_data: np.ndarray):
         self.COMPUTED_LAYER_DAO.insert_custom_layer(payload.name, self.get_type_name(), payload.specter_id,
                                                     payload.params if payload.params is not None else {})
-        path_to_save = os.path.join(os.path.dirname(payload.path), settings.CUSTOM_LAYER_FOLDER, payload.name + '.npy')
+        path_to_save = os.path.join(os.environ.get('DATA_PATH'), os.path.dirname(payload.path),
+                                    settings.CUSTOM_LAYER_FOLDER, payload.name + '.npy')
         np.save(path_to_save, layer_data)
 
     @abstractmethod
@@ -52,7 +53,7 @@ class Task(ABC):
         pass
 
     def __call__(self, payload: Payload):
-        self.id = payload.id
+        self.task_id = payload.task_id
         self._set_task_status(Status.STARTED)
         hyperspecter = self.DATA_PROVIDER.get_specter(payload.path)
         try:
