@@ -10,5 +10,5 @@ class CustomLayerDao:
         self.data_source = CustomLayerDataSource()
 
     def insert_custom_layer(self, name: str, type: str, specter_id: str, params: dict):
-        layer = CustomLayer.from_dict({"name": name, type: "type", "specterId": specter_id, "params": dumps(params)})
+        layer = CustomLayer.from_dict({"name": name, "type": type, "specterId": specter_id, "params": dumps(params)})
         self.data_source.insert_layer(layer)
