@@ -8,7 +8,7 @@ class CustomLayer(Base):
 
     id = Column(Integer, autoincrement=True, primary_key=True)
     specterId = Column(Integer, ForeignKey(Hyperspecter.id, ondelete='CASCADE'))
-    name = Column(String(length=100), nullable=False)
+    name = Column(String(length=100), nullable=True)
     type = Column(String(length=100), nullable=True)
     params = Column(String(length=500), nullable=True)
 
