@@ -4,7 +4,7 @@ from pydantic import BaseModel
 
 
 class Payload(BaseModel):
-    id: str
+    task_id: str
     specter_id: str
     name: str
     path: str
